@@ -31,10 +31,16 @@ class SimulatorDialog(QDialog):
     open_in_analysis_requested = pyqtSignal(str)
     rx_file_saved = pyqtSignal(str)
 
-    def __init__(self, simulator_config, modulators,
-                 expression_parser, project_manager: ProjectManager, signals: list = None,
-                 signal_tree_model=None,
-                 parent=None):
+    def __init__(
+        self,
+        simulator_config,
+        modulators,
+        expression_parser,
+        project_manager: ProjectManager,
+        signals: list = None,
+        signal_tree_model=None,
+        parent=None,
+    ):
         super().__init__(parent)
         self.ui = Ui_DialogSimulator()
         self.ui.setupUi(self)
@@ -48,8 +54,9 @@ class SimulatorDialog(QDialog):
 
         self.current_transcript_index = 0
 
-        self.simulator_scene = SimulatorScene(mode=1,
-                                              simulator_config=self.simulator_config)
+        self.simulator_scene = SimulatorScene(
+            mode=1, simulator_config=self.simulator_config
+        )
         self.ui.gvSimulator.setScene(self.simulator_scene)
         self.project_manager = project_manager
 
@@ -59,17 +66,22 @@ class SimulatorDialog(QDialog):
 
         self.backend_handler = BackendHandler()
         if self.rx_needed:
-            self.device_settings_rx_widget = DeviceSettingsWidget(project_manager,
-                                                                  is_tx=False,
-                                                                  backend_handler=self.backend_handler)
+            self.device_settings_rx_widget = DeviceSettingsWidget(
+                project_manager, is_tx=False, backend_handler=self.backend_handler
+            )
 
-            self.sniff_settings_widget = SniffSettingsWidget(self.device_settings_rx_widget.ui.cbDevice.currentText(),
-                                                             project_manager,
-                                                             signal=None,
-                                                             backend_handler=self.backend_handler,
-                                                             network_raw_mode=True, signals=signals)
+            self.sniff_settings_widget = SniffSettingsWidget(
+                self.device_settings_rx_widget.ui.cbDevice.currentText(),
+                project_manager,
+                signal=None,
+                backend_handler=self.backend_handler,
+                network_raw_mode=True,
+                signals=signals,
+            )
 
-            self.device_settings_rx_widget.device = self.sniff_settings_widget.sniffer.rcv_device
+            self.device_settings_rx_widget.device = (
+                self.sniff_settings_widget.sniffer.rcv_device
+            )
 
             self.sniff_settings_widget.ui.lineEdit_sniff_OutputFile.hide()
             self.sniff_settings_widget.ui.label_sniff_OutputFile.hide()
@@ -77,15 +89,23 @@ class SimulatorDialog(QDialog):
             self.sniff_settings_widget.ui.checkBox_sniff_Timestamp.hide()
             self.sniff_settings_widget.ui.comboBox_sniff_viewtype.hide()
 
-            self.ui.scrollAreaWidgetContentsRX.layout().insertWidget(0, self.device_settings_rx_widget)
-            self.ui.scrollAreaWidgetContentsRX.layout().insertWidget(1, self.sniff_settings_widget)
+            self.ui.scrollAreaWidgetContentsRX.layout().insertWidget(
+                0, self.device_settings_rx_widget
+            )
+            self.ui.scrollAreaWidgetContentsRX.layout().insertWidget(
+                1, self.sniff_settings_widget
+            )
 
             sniffer = self.sniff_settings_widget.sniffer
 
-            self.scene_manager = SniffSceneManager(np.array([], dtype=sniffer.rcv_device.data_type), parent=self)
+            self.scene_manager = SniffSceneManager(
+                np.array([], dtype=sniffer.rcv_device.data_type), parent=self
+            )
             self.ui.graphicsViewPreview.setScene(self.scene_manager.scene)
         else:
-            self.device_settings_rx_widget = self.sniff_settings_widget = self.scene_manager = None
+            self.device_settings_rx_widget = (
+                self.sniff_settings_widget
+            ) = self.scene_manager = None
             self.ui.tabWidgetSimulatorSettings.setTabEnabled(1, False)
             self.ui.graphicsViewPreview.hide()
             self.ui.btnSaveRX.hide()
@@ -94,17 +114,25 @@ class SimulatorDialog(QDialog):
             sniffer = None
 
         if self.tx_needed:
-            self.device_settings_tx_widget = DeviceSettingsWidget(project_manager, is_tx=True,
-                                                                  backend_handler=self.backend_handler,
-                                                                  continuous_send_mode=True)
+            self.device_settings_tx_widget = DeviceSettingsWidget(
+                project_manager,
+                is_tx=True,
+                backend_handler=self.backend_handler,
+                continuous_send_mode=True,
+            )
             self.device_settings_tx_widget.ui.spinBoxNRepeat.hide()
             self.device_settings_tx_widget.ui.labelNRepeat.hide()
 
-            self.modulation_settings_widget = ModulationSettingsWidget(modulators, signal_tree_model=signal_tree_model,
-                                                                       parent=None)
+            self.modulation_settings_widget = ModulationSettingsWidget(
+                modulators, signal_tree_model=signal_tree_model, parent=None
+            )
 
-            self.ui.scrollAreaWidgetContentsTX.layout().insertWidget(0, self.device_settings_tx_widget)
-            self.ui.scrollAreaWidgetContentsTX.layout().insertWidget(1, self.modulation_settings_widget)
+            self.ui.scrollAreaWidgetContentsTX.layout().insertWidget(
+                0, self.device_settings_tx_widget
+            )
+            self.ui.scrollAreaWidgetContentsTX.layout().insertWidget(
+                1, self.modulation_settings_widget
+            )
             send_device = self.device_settings_tx_widget.ui.cbDevice.currentText()
             sender = EndlessSender(self.backend_handler, send_device)
         else:
@@ -113,8 +141,14 @@ class SimulatorDialog(QDialog):
 
             sender = None
 
-        self.simulator = Simulator(self.simulator_config, modulators, expression_parser, project_manager,
-                                   sniffer=sniffer, sender=sender)
+        self.simulator = Simulator(
+            self.simulator_config,
+            modulators,
+            expression_parser,
+            project_manager,
+            sniffer=sniffer,
+            sender=sender,
+        )
 
         if self.device_settings_tx_widget:
             self.device_settings_tx_widget.device = self.simulator.sender.device
@@ -130,28 +164,48 @@ class SimulatorDialog(QDialog):
 
         self.ui.textEditTranscript.setFont(util.get_monospace_font())
 
-        if settings.read('default_view', 0, int) == 1:
+        if settings.read("default_view", 0, int) == 1:
             self.ui.radioButtonTranscriptHex.setChecked(True)
 
     def create_connects(self):
         if self.rx_needed:
-            self.device_settings_rx_widget.selected_device_changed.connect(self.on_selected_rx_device_changed)
-            self.device_settings_rx_widget.device_parameters_changed.connect(self.rx_parameters_changed.emit)
+            self.device_settings_rx_widget.selected_device_changed.connect(
+                self.on_selected_rx_device_changed
+            )
+            self.device_settings_rx_widget.device_parameters_changed.connect(
+                self.rx_parameters_changed.emit
+            )
 
-            self.sniff_settings_widget.sniff_parameters_changed.connect(self.sniff_parameters_changed.emit)
+            self.sniff_settings_widget.sniff_parameters_changed.connect(
+                self.sniff_parameters_changed.emit
+            )
 
             self.ui.btnSaveRX.clicked.connect(self.on_btn_save_rx_clicked)
-            self.ui.checkBoxCaptureFullRX.clicked.connect(self.on_checkbox_capture_full_rx_clicked)
+            self.ui.checkBoxCaptureFullRX.clicked.connect(
+                self.on_checkbox_capture_full_rx_clicked
+            )
 
-            self.ui.btnTestSniffSettings.clicked.connect(self.on_btn_test_sniff_settings_clicked)
-            self.ui.btnOpenInAnalysis.clicked.connect(self.on_btn_open_in_analysis_clicked)
+            self.ui.btnTestSniffSettings.clicked.connect(
+                self.on_btn_test_sniff_settings_clicked
+            )
+            self.ui.btnOpenInAnalysis.clicked.connect(
+                self.on_btn_open_in_analysis_clicked
+            )
 
         if self.tx_needed:
-            self.device_settings_tx_widget.selected_device_changed.connect(self.on_selected_tx_device_changed)
-            self.device_settings_tx_widget.device_parameters_changed.connect(self.tx_parameters_changed.emit)
+            self.device_settings_tx_widget.selected_device_changed.connect(
+                self.on_selected_tx_device_changed
+            )
+            self.device_settings_tx_widget.device_parameters_changed.connect(
+                self.tx_parameters_changed.emit
+            )
 
-        self.ui.radioButtonTranscriptBit.clicked.connect(self.on_radio_button_transcript_bit_clicked)
-        self.ui.radioButtonTranscriptHex.clicked.connect(self.on_radio_button_transcript_hex_clicked)
+        self.ui.radioButtonTranscriptBit.clicked.connect(
+            self.on_radio_button_transcript_bit_clicked
+        )
+        self.ui.radioButtonTranscriptHex.clicked.connect(
+            self.on_radio_button_transcript_hex_clicked
+        )
 
         self.simulator_scene.selectionChanged.connect(self.update_buttons)
         self.simulator_config.items_updated.connect(self.update_buttons)
@@ -169,32 +223,47 @@ class SimulatorDialog(QDialog):
 
     def update_buttons(self):
         selectable_items = self.simulator_scene.selectable_items()
-        all_items_selected = all(item.model_item.logging_active for item in selectable_items)
-        any_item_selected = any(item.model_item.logging_active for item in selectable_items)
+        all_items_selected = all(
+            item.model_item.logging_active for item in selectable_items
+        )
+        any_item_selected = any(
+            item.model_item.logging_active for item in selectable_items
+        )
         self.ui.btnToggleLog.setEnabled(len(self.simulator_scene.selectedItems()))
         self.ui.btnLogAll.setEnabled(not all_items_selected)
         self.ui.btnLogNone.setEnabled(any_item_selected)
 
     def __get_full_transcript(self) -> list:
-        return self.simulator.transcript.get_for_all_participants(all_rounds=True,
-                                                                  use_bit=self.ui.radioButtonTranscriptBit.isChecked())
+        return self.simulator.transcript.get_for_all_participants(
+            all_rounds=True, use_bit=self.ui.radioButtonTranscriptBit.isChecked()
+        )
 
     def update_view(self):
-        for device_message in filter(None, map(str.rstrip, self.simulator.device_messages())):
+        for device_message in filter(
+            None, map(str.rstrip, self.simulator.device_messages())
+        ):
             self.ui.textEditDevices.append(device_message)
 
-        for log_msg in filter(None, map(str.rstrip, self.simulator.read_log_messages())):
+        for log_msg in filter(
+            None, map(str.rstrip, self.simulator.read_log_messages())
+        ):
             self.ui.textEditSimulation.append(log_msg)
 
         transcript = self.__get_full_transcript()
-        for line in transcript[self.current_transcript_index:]:
+        for line in transcript[self.current_transcript_index :]:
             self.ui.textEditTranscript.append(line)
 
         self.current_transcript_index = len(transcript)
-        current_repeat = str(self.simulator.current_repeat + 1) if self.simulator.is_simulating else "-"
+        current_repeat = (
+            str(self.simulator.current_repeat + 1)
+            if self.simulator.is_simulating
+            else "-"
+        )
         self.ui.lblCurrentRepeatValue.setText(current_repeat)
 
-        current_item = self.simulator.current_item.index() if self.simulator.is_simulating else "-"
+        current_item = (
+            self.simulator.current_item.index() if self.simulator.is_simulating else "-"
+        )
         self.ui.lblCurrentItemValue.setText(current_item)
 
     def update_rx_graphics_view(self):
@@ -230,7 +299,7 @@ class SimulatorDialog(QDialog):
     def closeEvent(self, event: QCloseEvent):
         self.timer.stop()
         self.simulator.stop()
-        time.sleep(0.1)
+
         self.simulator.cleanup()
 
         self.emit_editing_finished_signals()
@@ -301,7 +370,9 @@ class SimulatorDialog(QDialog):
 
     @pyqtSlot()
     def on_btn_save_log_clicked(self):
-        file_path = QFileDialog.getSaveFileName(self, "Save log", "", "Log file (*.log)")
+        file_path = QFileDialog.getSaveFileName(
+            self, "Save log", "", "Log file (*.log)"
+        )
 
         if file_path[0] == "":
             return
@@ -316,7 +387,9 @@ class SimulatorDialog(QDialog):
 
     @pyqtSlot()
     def on_btn_save_transcript_clicked(self):
-        file_path = QFileDialog.getSaveFileName(self, "Save transcript", "", "Text file (*.txt)")
+        file_path = QFileDialog.getSaveFileName(
+            self, "Save transcript", "", "Text file (*.txt)"
+        )
 
         if file_path[0] == "":
             return
@@ -339,7 +412,9 @@ class SimulatorDialog(QDialog):
                 self.sniff_settings_widget.emit_editing_finished_signals()
 
                 self.simulator.sniffer.rcv_device.current_index = 0
-                self.simulator.sniffer.rcv_device.resume_on_full_receive_buffer = not self.ui.checkBoxCaptureFullRX.isChecked()
+                self.simulator.sniffer.rcv_device.resume_on_full_receive_buffer = (
+                    not self.ui.checkBoxCaptureFullRX.isChecked()
+                )
 
             if self.tx_needed:
                 self.device_settings_tx_widget.emit_editing_finished_signals()
@@ -372,16 +447,26 @@ class SimulatorDialog(QDialog):
     @pyqtSlot()
     def on_btn_test_sniff_settings_clicked(self):
         def on_dialog_finished():
-            self.device_settings_rx_widget.bootstrap(self.project_manager.simulator_rx_conf)
+            self.device_settings_rx_widget.bootstrap(
+                self.project_manager.simulator_rx_conf
+            )
             self.sniff_settings_widget.bootstrap(self.project_manager.device_conf)
 
         self.device_settings_rx_widget.emit_device_parameters_changed()
         self.sniff_settings_widget.emit_sniff_parameters_changed()
 
-        psd = ProtocolSniffDialog(self.project_manager, signals=self.sniff_settings_widget.signals, parent=self)
+        psd = ProtocolSniffDialog(
+            self.project_manager,
+            signals=self.sniff_settings_widget.signals,
+            parent=self,
+        )
         psd.device_settings_widget.bootstrap(self.project_manager.simulator_rx_conf)
-        psd.device_settings_widget.device_parameters_changed.connect(self.rx_parameters_changed.emit)
-        psd.sniff_settings_widget.sniff_parameters_changed.connect(self.sniff_parameters_changed.emit)
+        psd.device_settings_widget.device_parameters_changed.connect(
+            self.rx_parameters_changed.emit
+        )
+        psd.sniff_settings_widget.sniff_parameters_changed.connect(
+            self.sniff_parameters_changed.emit
+        )
         psd.finished.connect(on_dialog_finished)
         psd.ui.btnAccept.hide()
         psd.show()
@@ -399,27 +484,39 @@ class SimulatorDialog(QDialog):
             return
 
         if self.ui.checkBoxCaptureFullRX.isChecked():
-            self.scene_manager = LiveSceneManager(np.array([], dtype=self.simulator.sniffer.rcv_device.data_type),
-                                                  parent=self)
+            self.scene_manager = LiveSceneManager(
+                np.array([], dtype=self.simulator.sniffer.rcv_device.data_type),
+                parent=self,
+            )
             self.ui.graphicsViewPreview.setScene(self.scene_manager.scene)
         else:
-            self.scene_manager = SniffSceneManager(np.array([], dtype=self.simulator.sniffer.rcv_device.data_type),
-                                                   parent=self)
+            self.scene_manager = SniffSceneManager(
+                np.array([], dtype=self.simulator.sniffer.rcv_device.data_type),
+                parent=self,
+            )
 
             self.ui.graphicsViewPreview.setScene(self.scene_manager.scene)
 
     @pyqtSlot()
     def on_checkbox_capture_full_rx_clicked(self):
-        self.simulator.sniffer.rcv_device.resume_on_full_receive_buffer = not self.ui.checkBoxCaptureFullRX.isChecked()
+        self.simulator.sniffer.rcv_device.resume_on_full_receive_buffer = (
+            not self.ui.checkBoxCaptureFullRX.isChecked()
+        )
         self.__set_rx_scene()
 
     @pyqtSlot()
     def on_btn_save_rx_clicked(self):
         rx_device = self.simulator.sniffer.rcv_device
-        if isinstance(rx_device.data, np.ndarray) or isinstance(rx_device.data, IQArray):
-            data = IQArray(rx_device.data[:rx_device.current_index])
-            filename = FileOperator.save_data_dialog("simulation_capture", data,
-                                                     sample_rate=rx_device.sample_rate, parent=self)
+        if isinstance(rx_device.data, np.ndarray) or isinstance(
+            rx_device.data, IQArray
+        ):
+            data = IQArray(rx_device.data[: rx_device.current_index])
+            filename = FileOperator.ask_signal_file_name_and_save(
+                "simulation_capture",
+                data,
+                sample_rate=rx_device.sample_rate,
+                parent=self,
+            )
             if filename:
                 data.tofile(filename)
                 self.rx_file_saved.emit(filename)
