@@ -1,5 +1,5 @@
-VERSION = "2.9.5" 
+VERSION = "2.9.6" 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     # To read out version easy on command line for InnoSetup
     print(VERSION)
